@@ -5,11 +5,14 @@
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include <quick-lint-js/narrow-cast.h>
+#include <quick-lint-js/process.h>
+#include <quick-lint-js/util/cast.h>
 #include <sys/wait.h>
 #include <unistd.h>
 
 namespace quick_lint_js {
+// TODO(strager): Reuse wait_for_process_exit from
+// <quick-lint-js/port/child-process.h>.
 void wait_for_process_exit(::pid_t pid) {
 retry:
   int status;
