@@ -1,10 +1,9 @@
 // Copyright (C) 2020  Matthew "strager" Glazar
 // See end of file for extended copyright information.
 
-#ifndef QUICK_LINT_JS_VERSION_H
-#define QUICK_LINT_JS_VERSION_H
+#pragma once
 
-#include <quick-lint-js/cpp.h>
+#include <quick-lint-js/util/cpp.h>
 
 // QUICK_LINT_JS_VERSION is normally defined by the build system (CMake).
 #if !defined(QUICK_LINT_JS_VERSION)
@@ -15,7 +14,8 @@
 #define QUICK_LINT_JS_VERSION_STRING_U8 \
   QLJS_CPP_CONCAT(u8, QUICK_LINT_JS_VERSION_STRING)
 
-#endif
+#define QUICK_LINT_JS_VERSION_STRING_U8_SV \
+  QLJS_CPP_CONCAT(QUICK_LINT_JS_VERSION_STRING_U8, _sv)
 
 // quick-lint-js finds bugs in JavaScript programs.
 // Copyright (C) 2020  Matthew "strager" Glazar
